version

package
v1.1.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 13, 2026 License: AGPL-3.0 Imports: 1 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var (
	Version = "dev"
	Commit  = "none"
	Date    = "unknown"
)

These variables are set at build time via ldflags.

Functions

func Info

func Info() string

Info returns a formatted version string suitable for --version output.

Types

This section is empty.

Jump to